Module builder

Module builder 

Video decoder builder for constructing video decoders with custom configuration.

This module provides the VideoDecoderBuilder type which enables fluent configuration of video decoders. Use VideoDecoder::open() to start building.

Examples

use ff_decode::{VideoDecoder, HardwareAccel};
use ff_format::PixelFormat;

let decoder = VideoDecoder::open("video.mp4")?
    .output_format(PixelFormat::Rgba)
    .hardware_accel(HardwareAccel::Auto)
    .thread_count(4)
    .build()?;

Structs

VideoDecoder
A video decoder for extracting frames from media files.
VideoDecoderBuilder
Builder for configuring and constructing a VideoDecoder.