Audio decoding module.
This module provides the audio decoder implementation for extracting audio frames from media files.
Re-exports
pub use builder::AudioDecoder;pub use builder::AudioDecoderBuilder;
Modules
- builder
- Audio decoder builder for constructing audio decoders with custom configuration.
- decoder_
inner - Internal audio decoder implementation using FFmpeg.