Module audio

Module audio 

Audio decoding module.

This module provides the audio decoder implementation for extracting audio frames from media files.

Re-exports

pub use async_decoder::AsyncAudioDecoder;
pub use async_decoder::AsyncAudioDecoderBuilder;
pub use builder::AudioDecoder;
pub use builder::AudioDecoderBuilder;

Modules

async_decoder
Async audio decoder backed by tokio::task::spawn_blocking.
builder
Audio decoder builder for constructing audio decoders with custom configuration.
decoder_inner
Internal audio decoder implementation using FFmpeg.