Video decoding module.
This module provides the video decoder implementation for extracting video frames from media files with hardware acceleration support.
Re-exports
pub use builder::VideoDecoder;pub use builder::VideoDecoderBuilder;
Modules
- builder
- Video decoder builder for constructing video decoders with custom configuration.
- decoder_
inner - Internal video decoder implementation using FFmpeg.