Video decoding module.
This module provides the video decoder implementation for extracting video frames from media files with hardware acceleration support.
Re-exports
pub use async_decoder::AsyncVideoDecoder;pub use async_decoder::AsyncVideoDecoderBuilder;pub use builder::VideoDecoder;pub use builder::VideoDecoderBuilder;
Modules
- async_
decoder - Async video decoder backed by
tokio::task::spawn_blocking. - builder
- Video decoder builder for constructing video decoders with custom configuration.
- decoder_
inner - Internal video decoder implementation using FFmpeg.